library ieee;
use ieee.std_logic_1164.all;
entity dwnldpar is 
port(
-- parallel port data, control, and status pins
ppd: in std_logic_vector(7 downto 0); 
ppc: in std_logic_vector(3 downto 0); 
pps: out std_logic_vector(6 downto 3);

-- Virtex FPGA pins 11
V_a: in std_logic_vector(3 downto 0); -- inputs from Virtex 
V_tck: out std_logic; -- driver to Virtex JTAG clock 13
V_cclk: out std_logic; -- driver to Virtex config clock 14
V_progb: out std_logic; -- driver to Virtex program pin 15
V_initb: in std_logic; -- input from Virtex init pin 16
V_done: in std_logic; -- input from Virtex done pin 17
V_d: out std_logic_vector(7 downto 0); -- drivers to Virtex data pins 18
V_m: out std_logic_vector(2 downto 0); -- Virtex config mode pins 19
ceb: out std_logic; -- Flash chip-enable 21
resetb: out std_logic; -- reset for video input and Ethernet chips 22

--Ethernet I/O
ledlb: in std_logic; --not link
ledcb: in std_logic; --not collision
ledtb: in std_logic; --not xmit
ledrb: in std_logic; --not receive
ledsb: in std_logic; --not 100Mb
mf: out std_logic_vector(4 downto 0); -- Configuration 1
cfg: out std_logic_vector(1 downto 0); -- Configuration 2
mddis: out std_logic;
fde: out std_logic;

bar: out std_logic_vector(9 downto 0) -- LED bargraph 23
);
end dwnldpar;

architecture dwnldpar_arch of dwnldpar is 
constant LO: std_logic := '0'; 
constant HI: std_logic := '1'; 
constant SLAVE_SERIAL_MODE: std_logic_vector(2 downto 0) := "111"; 
begin
-- disable other chips on the XSV Board so they don't interfere 32
-- during the configuration of the Virtex FPGA 33
ceb <= HI; -- disable Flash 34
V_tck <= LO; -- deactivate Virtex JTAG circuit 35
-- disable the video input and Ethernet chips until config is done 36
resetb <= LO when V_done=LO else HI;
bar(9) <= not(ledlb);
bar(8) <= not(ledcb);
bar(7) <= not(ledtb);
bar(6) <= not(ledrb);
bar(5) <= not(ledsb);

-- Set Auto-Negotiate
mf(0) <= HI;
mf(1) <= LO;
mf(2) <= LO;
mf(3) <= LO;
mf(4) <= HI;

-- Set Advertise All
cfg(0) <= LO;
cfg(1) <= HI;

-- Enable Management
mddis <= LO;

-- Full Duplex
fde <= LO;

-- connect Virtex configuration pins 39
V_m <= SLAVE_SERIAL_MODE; -- set Virtex config mode pins 40
V_progb<= ppc(0); -- Virtex programming pulse comes from parallel port 41
V_cclk <= ppc(1); -- Virtex config clock comes from parallel port 42
-- config bitstream comes from parallel port control pin until 43
-- config is done and then gets driven by parallel port data pin 44
V_d(0) <= ppc(3) when V_done=LO else ppd(0);

-- connect the rest of the parallel port to the Virtex FPGA 47
V_d(7 downto 1) <= ppd(7 downto 1); -- data from PC 48
pps(6 downto 3) <= V_a(3 downto 0); -- status back to PC 49

-- display status of Virtex done and init pins on the bargraph LED 51
bar(0) <= V_done; 
bar(1) <= V_initb; 
end dwnldpar_arch; 
